summaryrefslogtreecommitdiffstats
path: root/kcontrol/kicker/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/kicker/main.cpp')
-rw-r--r--kcontrol/kicker/main.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kcontrol/kicker/main.cpp b/kcontrol/kicker/main.cpp
index daf9f283f..8bf4646df 100644
--- a/kcontrol/kicker/main.cpp
+++ b/kcontrol/kicker/main.cpp
@@ -351,13 +351,13 @@ TQString KickerConfig::quickHelp() const
" manipulation of the panel's buttons and applets.");
}
-KAboutData *KickerConfig::aboutData()
+TDEAboutData *KickerConfig::aboutData()
{
- // the KAboutDatas are deleted by the KCModules
- KAboutData *about
- = new KAboutData(I18N_NOOP("kcmkicker"),
+ // the TDEAboutDatas are deleted by the KCModules
+ TDEAboutData *about
+ = new TDEAboutData(I18N_NOOP("kcmkicker"),
I18N_NOOP("TDE Panel Control Module"),
- 0, 0, KAboutData::License_GPL,
+ 0, 0, TDEAboutData::License_GPL,
I18N_NOOP("(c) 2009 - 2010 Timothy Pearson\n"
"(c) 1999 - 2001 Matthias Elter\n"
"(c) 2002 - 2003 Aaron J. Seigo"));